#[non_exhaustive]pub struct HealthStatus {
pub(crate) ready: bool,
pub(crate) reason: String,
}Expand description
Reports whether a plugin is ready to accept tasks.
Constructed via HealthStatus::ready or HealthStatus::not_ready.
The daemon polls this periodically and will not dispatch tasks to a
plugin that reports not-ready.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.ready: boolreason: StringImplementations